@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: reducers
 version: 3.12.1
-id: reducers-3.12.1-9c0679f8e3a7104b42907174b9bc86fd
-key: reduc_2CjdjSKgYE7F5HQsUt2i9P
+id: reducers-3.12.1-643a8857fe1ff69e9322fcb3ed491f08
+key: reduc_1o3u20yr0x79475pkABv54
 license: BSD3
 copyright: Copyright (C) 2008-2013 Edward A. Kmett
 maintainer: Edward A. Kmett <ekmett@gmail.com>
@@ -26,19 +26,19 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/reducers-3.12.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/reducers-3.12.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/reducers-3.12.1
-hs-libraries: HSreducers-3.12.1-2CjdjSKgYE7F5HQsUt2i9P
+hs-libraries: HSreducers-3.12.1-1o3u20yr0x79475pkABv54
 depends:
     array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     fingertree-0.1.1.0-2b52886bad6677cc2ba4bb73e01240b3
-    hashable-1.2.4.0-f83fcc5c92d0a1ea59927aca6baa3161
-    semigroupoids-5.0.1-d6a1ac9616a3b8232f6b4a54c12a0db0
-    semigroups-0.18.1-4a4dee25d838ab8c8d38a0caa045cf78
-    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
+    hashable-1.2.4.0-165ac1864c8f5bd906b25f6a12db4f18
+    semigroupoids-5.0.1-7b21d348d4b507a23638386627368bec
+    semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
+    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
-    unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
+    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
 haddock-interfaces: /usr/share/doc/haskell-reducers/html/reducers.haddock
 haddock-html: /usr/share/doc/haskell-reducers/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
